# remirepo spec file for php-pecl-datadog-trace
#
# Copyright (c) 2019-2023 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%scl_package       php-pecl-datadog-trace
%else
%global _root_libdir %{_libdir}
%endif

# pecl name
%global proj_name  datadog_trace
# no underscore for package name
%global safe_name  datadog-trace
# extension name
%global pecl_name  ddtrace

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name   40-%{pecl_name}.ini

%bcond_without     tests

Summary:        APM and distributed tracing for PHP
Name:           %{?scl_prefix}php-pecl-datadog-trace
Version:        0.83.0
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
# extension is dual-licensed under Apache 2.0 or BSD3.
# mpack is MIT
License:        (Apache-2.0 OR BSD-3-Clause) AND MIT
URL:            https://pecl.php.net/package/%{proj_name}
Source0:        https://pecl.php.net/get/%{proj_name}-%{version}.tgz

# ddtrace only supports 64-bit platforms
ExcludeArch:    %{ix86} %{arm}

%if 0%{?rhel} == 7 && 0%{?dtsversion} == 0
BuildRequires:  devtoolset-6-toolchain
%global dtsversion 6
%global dtsenable source /opt/rh/devtoolset-6/enable
%global dtsprefix devtoolset-6-
%endif
BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-devel <  8.3
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  curl-devel
BuildRequires:  %{?scl_prefix}php-json
BuildRequires:  %{?scl_prefix}php-curl
# For tests
BuildRequires:  %{?scl_prefix}php-posix
#BuildRequires:  gdb
#BuildRequires:  %%{?scl_prefix}php-debuginfo
#BuildRequires:  %%{?scl_prefix}php-debugsource

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}
Requires:       %{?scl_prefix}php-json%{?_isa}
%if "%{php_version}" > "8.0"
Requires:       %{?scl_prefix}php-curl%{?_isa}
%endif

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})%{?_isa} = %{version}


%description
The Datadog PHP Tracer brings APM and distributed tracing to PHP.

Documentation: https://docs.datadoghq.com/tracing/languages/php/

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
mv %{proj_name}-%{version} NTS

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd NTS
: PEAR installer stuff
sed -e 's:@php_dir@:%{pear_phpdir}:' \
    -e 's:_BUILD_FROM_PECL_:1:' \
    -i ext/ddtrace.c \
       ext/configuration.h

: Sanity check, really often broken
extver=$(sed -n '/#define PHP_DDTRACE_VERSION /{s/.* "//;s/".*$//;p}' ext/version.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so

; Configuration
;ddtrace.disable = Off
;ddtrace.request_init_hook = '%{pear_phpdir}/datadog_trace/bridge/dd_wrap_autoloader.php'
;ddtrace.cgroup_file = '/proc/self/cgroup'
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --enable-ddtrace \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --enable-ddtrace \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# PEAR stuff
mkdir -p          %{buildroot}%{pear_phpdir}/datadog_trace/
cp -pr NTS/bridge %{buildroot}%{pear_phpdir}/datadog_trace/bridge

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
export DD_TRACE_CLI_ENABLED=1

# Erratic results
rm ?TS/tests/ext/segfault_backtrace_*.phpt
rm ?TS/tests/ext/sandbox/memory_limit_graceful_bailout.phpt
%if "%{php_version}" > "8.0"
rm ?TS/tests/ext/sandbox/fatal_errors_are_tracked_005.phpt
%endif
# XFAIL
rm ?TS/tests/ext/sandbox/hook_function/01.phpt
rm ?TS/tests/ext/sandbox/hook_method/01.phpt

# DEP for ext dependencies, MOD for ext used in tests
DEP=""
MOD="-n -d ddtrace.request_init_hook="
%if "%{php_version}" > "8.0"
[ -f %{php_extdir}/curl.so ]  && DEP="$DEP -d extension=curl.so"
%else
[ -f %{php_extdir}/curl.so ]  && MOD="$MOD -d extension=curl.so"
%endif
[ -f %{php_extdir}/json.so ]  && DEP="$DEP -d extension=json.so"
[ -f %{php_extdir}/posix.so ] && MOD="$MOD -d extension=posix.so"

cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini $DEP \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{_bindir}/php \
TEST_PHP_ARGS="$DEP $MOD -d extension=$PWD/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{_bindir}/php -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini $DEP \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{proj_name} >/dev/null || :
fi
%endif


%files
%doc %{pecl_docdir}/%{pecl_name}
%{?_licensedir:%license NTS/LICENSE*}
%dir %{pear_phpdir}/datadog_trace
     %{pear_phpdir}/datadog_trace/bridge

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Sat Jan 14 2023 Remi Collet <remi@remirepo.net> - 0.83.0-1
- update to 0.83.0

* Wed Dec  7 2022 Remi Collet <remi@remirepo.net> - 0.82.0-1
- update to 0.82.0

* Thu Nov  3 2022 Remi Collet <remi@remirepo.net> - 0.81.1-1
- update to 0.81.1

* Wed Nov  2 2022 Remi Collet <remi@remirepo.net> - 0.81.0-1
- update to 0.81.0

* Thu Sep 29 2022 Remi Collet <remi@remirepo.net> - 0.80.0-1
- update to 0.80.0

* Fri Sep  9 2022 Remi Collet <remi@remirepo.net> - 0.79.0-1
- update to 0.79.0

* Mon Aug 29 2022 Remi Collet <remi@remirepo.net> - 0.78.0-1
- update to 0.78.0

* Wed Aug  3 2022 Remi Collet <remi@remirepo.net> - 0.77.0-1
- update to 0.77.0

* Fri Jul 29 2022 Remi Collet <remi@remirepo.net> - 0.76.2-1
- update to 0.76.2

* Mon Jul 18 2022 Remi Collet <remi@remirepo.net> - 0.76.1-1
- update to 0.76.1

* Mon Jul 11 2022 Remi Collet <remi@remirepo.net> - 0.76.0-1
- update to 0.76.0
- drop PHP 5 support

* Mon Jun 13 2022 Remi Collet <remi@remirepo.net> - 0.75.0-1
- update to 0.75.0

* Thu May 12 2022 Remi Collet <remi@remirepo.net> - 0.74.0-1
- update to 0.74.0

* Thu Apr 28 2022 Remi Collet <remi@remirepo.net> - 0.73.0-1
- update to 0.73.0

* Thu Apr  7 2022 Remi Collet <remi@remirepo.net> - 0.72.0-1
- update to 0.72.0

* Fri Apr  1 2022 Remi Collet <remi@remirepo.net> - 0.71.1-1
- update to 0.71.1

* Tue Mar 15 2022 Remi Collet <remi@remirepo.net> - 0.71.0-1
- update to 0.71.0

* Thu Mar  3 2022 Remi Collet <remi@remirepo.net> - 0.70.1-1
- update to 0.70.1

* Mon Feb  7 2022 Remi Collet <remi@remirepo.net> - 0.70.0-1
- update to 0.70.0

* Tue Jan 25 2022 Remi Collet <remi@remirepo.net> - 0.69.0-1
- update to 0.69.0

* Mon Jan 10 2022 Remi Collet <remi@remirepo.net> - 0.68.2-1
- update to 0.68.2

* Fri Dec 31 2021 Remi Collet <remi@remirepo.net> - 0.68.1-1
- update to 0.68.1

* Thu Dec 23 2021 Remi Collet <remi@remirepo.net> - 0.68.0-1
- update to 0.68.0

* Tue Nov  2 2021 Remi Collet <remi@remirepo.net> - 0.67.0-1
- update to 0.67.0

* Tue Oct 12 2021 Remi Collet <remi@remirepo.net> - 0.66.0-1
- update to 0.66.0

* Wed Sep 22 2021 Remi Collet <remi@remirepo.net> - 0.65.1-1
- update to 0.65.1

* Tue Sep 21 2021 Remi Collet <remi@remirepo.net> - 0.65.0-1
- update to 0.65.0

* Wed Sep  8 2021 Remi Collet <remi@remirepo.net> - 0.64.1-1
- update to 0.64.1

* Fri Sep  3 2021 Remi Collet <remi@remirepo.net> - 0.64.0-1
- update to 0.64.0

* Mon Aug 23 2021 Remi Collet <remi@remirepo.net> - 0.63.0-1
- update to 0.63.0

* Thu Jul 29 2021 Remi Collet <remi@remirepo.net> - 0.62.1-1
- update to 0.62.1

* Wed Jul 21 2021 Remi Collet <remi@remirepo.net> - 0.62.0-1
- update to 0.62.0

* Tue Jul 13 2021 Remi Collet <remi@remirepo.net> - 0.61.0-1
- update to 0.61.0

* Sat May 29 2021 Remi Collet <remi@remirepo.net> - 0.60.0-1
- update to 0.60.0

* Fri May  7 2021 Remi Collet <remi@remirepo.net> - 0.59.0-1
- update to 0.59.0

* Thu Apr 22 2021 Remi Collet <remi@remirepo.net> - 0.58.0-1
- update to 0.58.0

* Fri Mar  5 2021 Remi Collet <remi@remirepo.net> - 0.56.0-1
- update to 0.56.0

* Fri Feb  5 2021 Remi Collet <remi@remirepo.net> - 0.55.0-1
- update to 0.55.0
- open https://github.com/DataDog/dd-trace-php/pull/1144
  add missing dependency on curl extension for PHP 8

* Thu Jan 21 2021 Remi Collet <remi@remirepo.net> - 0.54.0-1
- update to 0.54.0

* Thu Dec 31 2020 Remi Collet <remi@remirepo.net> - 0.53.0-1
- update to 0.53.0

* Tue Dec  1 2020 Remi Collet <remi@remirepo.net> - 0.52.0-1
- update to 0.52.0

* Wed Nov 18 2020 Remi Collet <remi@remirepo.net> - 0.51.0-1
- update to 0.51.0

* Fri Nov  6 2020 Remi Collet <remi@remirepo.net> - 0.50.0-1
- update to 0.50.0

* Thu Oct 15 2020 Remi Collet <remi@remirepo.net> - 0.49.0-1
- update to 0.49.0
- allow PHP 5.4 and 5.5

* Tue Sep 22 2020 Remi Collet <remi@remirepo.net> - 0.48.3-1
- update to 0.48.3

* Fri Sep 11 2020 Remi Collet <remi@remirepo.net> - 0.48.2-1
- update to 0.48.2

* Tue Sep  1 2020 Remi Collet <remi@remirepo.net> - 0.48.1-1
- update to 0.48.1

* Wed Aug 26 2020 Remi Collet <remi@remirepo.net> - 0.48.0-1
- update to 0.48.0
- drop patch merged upstream
- install PHP library
- raise dependency on PHP 5.6

* Sat Aug  1 2020 Remi Collet <remi@remirepo.net> - 0.47.1-1
- update to 0.47.1

* Thu Jul  9 2020 Remi Collet <remi@remirepo.net> - 0.47.0-1
- update to 0.47.0
- open https://github.com/DataDog/dd-trace-php/pull/952
  improve CGI usage in test suite
- open https://github.com/DataDog/dd-trace-php/issues/953
  missing files in 0.47.0 archive

* Wed Jun  3 2020 Remi Collet <remi@remirepo.net> - 0.46.0-1
- update to 0.46.0
- open https://github.com/DataDog/dd-trace-php/issues/912
  failed test and segfault in test suite
- open https://github.com/DataDog/dd-trace-php/issues/913
  missing file for 5.4

* Tue May 19 2020 Remi Collet <remi@remirepo.net> - 0.45.1-1
- update to 0.45.1

* Wed May 13 2020 Remi Collet <remi@remirepo.net> - 0.45.0-1
- update to 0.45.0

* Thu Apr 30 2020 Remi Collet <remi@remirepo.net> - 0.44.1-1
- update to 0.44.1

* Wed Apr 29 2020 Remi Collet <remi@remirepo.net> - 0.44.0-1
- update to 0.44.0

* Thu Apr 23 2020 Remi Collet <remi@remirepo.net> - 0.43.0-1
- update to 0.43.0

* Thu Apr  2 2020 Remi Collet <remi@remirepo.net> - 0.42.0-1
- update to 0.42.0

* Wed Mar 11 2020 Remi Collet <remi@remirepo.net> - 0.41.1-1
- update to 0.41.1
- re-enable ZTS build

* Tue Mar  3 2020 Remi Collet <remi@remirepo.net> - 0.41.0-1
- update to 0.41.0
- disable ZTS build reported as
  https://github.com/DataDog/dd-trace-php/issues/782

* Thu Feb 20 2020 Remi Collet <remi@remirepo.net> - 0.40.0-1
- update to 0.40.0

* Fri Jan 31 2020 Remi Collet <remi@remirepo.net> - 0.39.0-1
- update to 0.39.0

* Wed Jan 29 2020 Remi Collet <remi@remirepo.net> - 0.38.1-1
- update to 0.38.1

* Tue Jan 28 2020 Remi Collet <remi@remirepo.net> - 0.38.0-1
- update to 0.38.0
- fix License: (ASL 2.0 or BSD) and MIT

* Thu Jan  9 2020 Remi Collet <remi@remirepo.net> - 0.37.0-1
- update to 0.37.0
- open tests/ext/sandbox/memory_limit_graceful_bailout.phpt failed test

* Thu Dec 19 2019 Remi Collet <remi@remirepo.net> - 0.36.0-1
- update to 0.36.0

* Fri Dec  6 2019 Remi Collet <remi@remirepo.net> - 0.35.0-1
- update to 0.35.0

* Tue Nov 12 2019 Remi Collet <remi@remirepo.net> - 0.34.1-1
- update to 0.34.1

* Wed Oct 30 2019 Remi Collet <remi@remirepo.net> - 0.34.0-1
- update to 0.34.0

* Thu Oct 17 2019 Remi Collet <remi@remirepo.net> - 0.33.0-1
- update to 0.33.0 (no change)

* Thu Oct 10 2019 Remi Collet <remi@remirepo.net> - 0.32.1-1
- update to 0.32.1 (no change)

* Fri Oct  4 2019 Remi Collet <remi@remirepo.net> - 0.31.0-1
- update to 0.31.0

* Thu Sep 19 2019 Remi Collet <remi@remirepo.net> - 0.30.2-1
- update to 0.30.2
- add upstream patch for PHP 7.4

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.30.0-2
- rebuild for 7.4.0RC1

* Fri Aug  9 2019 Remi Collet <remi@remirepo.net> - 0.30.0-1
- update to 0.30.0

* Wed Jul  3 2019 Remi Collet <remi@remirepo.net> - 0.29.0-1
- update to 0.29.0

* Tue Jun 25 2019 Remi Collet <remi@remirepo.net> - 0.28.1-1
- update to 0.28.1
- update options in provided configuration

* Thu Jun 20 2019 Remi Collet <remi@remirepo.net> - 0.28.0-1
- update to 0.28.0

* Fri Jun  7 2019 Remi Collet <remi@remirepo.net> - 0.27.2-1
- update to 0.27.2

* Thu Jun  6 2019 Remi Collet <remi@remirepo.net> - 0.27.1-1
- update to 0.27.1

* Sat Jun  1 2019 Remi Collet <remi@remirepo.net> - 0.26.0-1
- update to 0.26.0
- drop patch merged upstream

* Mon May 27 2019 Remi Collet <remi@remirepo.net> - 0.23.0-2
- add patch for 7.4 from
  https://github.com/DataDog/dd-trace-php/pull/452

* Fri May 10 2019 Remi Collet <remi@remirepo.net> - 0.23.0-1
- update to 0.23.0 (no change)

* Wed May  8 2019 Remi Collet <remi@remirepo.net> - 0.22.0-1
- update to 0.22.0

* Thu May  2 2019 Remi Collet <remi@remirepo.net> - 0.21.0-1
- update to 0.21.0
- drop patch merged upstream

* Fri Apr 26 2019 Remi Collet <remi@remirepo.net> - 0.20.0-1
- update to 0.20.0
- add patch for test suite on 7.3 from
  https://github.com/DataDog/dd-trace-php/pull/412

* Sun Apr 14 2019 Remi Collet <remi@remirepo.net> - 0.19.0-1
- update to 0.19.0

* Tue Apr  9 2019 Remi Collet <remi@remirepo.net> - 0.18.0-2
- test build

* Tue Apr  9 2019 Remi Collet <remi@remirepo.net> - 0.18.0-1
- update to 0.18.0
- open https://github.com/DataDog/dd-trace-php/issues/393
  missing files in pecl archive, and open
  https://github.com/DataDog/dd-trace-php/pull/397
- open https://github.com/DataDog/dd-trace-php/issues/394
  failed test on 32-bit build
- open https://github.com/DataDog/dd-trace-php/issues/395
  build failure with old GCC, and open
  https://github.com/DataDog/dd-trace-php/pull/396

* Wed Mar 27 2019 Remi Collet <remi@remirepo.net> - 0.17.0-1
- update to 0.17.0 (no change)

* Thu Mar 21 2019 Remi Collet <remi@remirepo.net> - 1.16.1-1
- update to 1.16.1 (no change)

* Wed Mar 20 2019 Remi Collet <remi@remirepo.net> - 0.16.0-1
- update to 0.16.0
- update provided configuration

* Tue Mar 12 2019 Remi Collet <remi@remirepo.net> - 0.15.1-1
- update to 0.15.1 (stable)

* Wed Feb 27 2019 Remi Collet <remi@remirepo.net> - 0.14.1-1
- update to 0.14.1

* Wed Feb 27 2019 Remi Collet <remi@remirepo.net> - 0.14.0-1
- update to 0.14.0
- update provided configuration

* Mon Feb 25 2019 Remi Collet <remi@remirepo.net> - 0.13.4-1
- update to 0.13.4

* Tue Feb 19 2019 Remi Collet <remi@remirepo.net> - 0.13.3-1
- update to 0.13.3

* Tue Feb 19 2019 Remi Collet <remi@remirepo.net> - 0.13.2-1
- update to 0.13.2

* Wed Feb 13 2019 Remi Collet <remi@remirepo.net> - 0.13.1-1
- update to 0.13.1

* Wed Feb 13 2019 Remi Collet <remi@remirepo.net> - 0.13.0-1
- update to 0.13.0

* Sat Feb  2 2019 Remi Collet <remi@remirepo.net> - 0.12.0-1
- update to 0.12.0

* Wed Jan 30 2019 Remi Collet <remi@remirepo.net> - 0.11.0-1
- update to 0.11.0
- open https://github.com/DataDog/dd-trace-php/issues/271 PHP 5 ZTS

* Tue Jan 22 2019 Remi Collet <remi@remirepo.net> - 0.10.0-1
- update to 0.10.0
- open https://github.com/DataDog/dd-trace-php/issues/249 missing files
- open https://github.com/DataDog/dd-trace-php/issues/250 PHP compat
- open https://github.com/DataDog/dd-trace-php/issues/253 PHP 5.4 ZTS

* Sat Jan 12 2019 Remi Collet <remi@remirepo.net> - 0.9.1-1
- update to 0.9.1

* Tue Jan  8 2019 Remi Collet <remi@remirepo.net> - 0.9.0-1
- update to 0.9.0

* Fri Jan  4 2019 Remi Collet <remi@remirepo.net> - 0.8.1-1
- initial package, version 0.8.1 (beta)
- open https://github.com/DataDog/dd-trace-php/issues/213 PHP < 5.6
- open https://github.com/DataDog/dd-trace-php/issues/212 PHP 7.3
